==> qtop_2.3.1.orig.tar.gz: Top-2.3.1/base-qt/TextEditionDelegate.h <==
#ifndef TextEditionDelegate_h
#define TextEditionDelegate_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TreeViewItemDelegate.h"

class TextEditionDelegate : public TreeViewItemDelegate, public Counter
{

    public:

    //! constructor
    TextEditionDelegate(QObject *parent = 0);

    //! create editor
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;

    //! set editor data
    void setEditorData(QWidget *editor, const QModelIndex &index) const;

    //! set model data from editor
    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;

    //! editor geometry
    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const;

};

#endif

==> qtop_2.3.4.orig.tar.gz: Top-2.3.4/base-qt/TextEditionDelegate.h <==
#ifndef TextEditionDelegate_h
#define TextEditionDelegate_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TreeViewItemDelegate.h"

class TextEditionDelegate : public TreeViewItemDelegate, private Base::Counter<TextEditionDelegate>
{

    Q_OBJECT

    public:

    //* constructor
    explicit TextEditionDelegate( QObject* = nullptr );

    //* create editor
    QWidget *createEditor( QWidget*, const QStyleOptionViewItem&, const QModelIndex& ) const;

    //* set editor data
    void setEditorData( QWidget*, const QModelIndex& ) const;

    //* set model data from editor
    void setModelData( QWidget*, QAbstractItemModel*, const QModelIndex& ) const;

    //* editor geometry
    void updateEditorGeometry( QWidget*, const QStyleOptionViewItem&, const QModelIndex& ) const;

};

#endif
